Donate : 
https://paypal.me/kadioham
Contact : 
kadioham@outlook.com

Reqplus
===================
A module for requiring Java & .Net & files using specified path to the entry method which returns the export object

----------


Example
-------------

In this example we will define custom entry-method path & custom file encoding

let's assume that we have test.cs contains 2 classes which have the proper methods to be the entry-method
```
using System;

namespace someNS {
    public class SomeClass {
        public static dynamic SomeMethod(dynamic pars) {
            return new { Export = pars.name };
        }
    }
}
namespace Require {
    public class From {
        public static dynamic This(dynamic pars) {
            return new { This = pars.name };
        }
    }
}
```
from your javascript code :
```
require = require('reqplus');
var obj = require({
            file: 'test.cs',
            encoding: 'utf-8',
            entry: 'SomeNS.SomeClass.SomeMethod',
            pars: { name : "Hello world"}
        });

console.log(obj);
```
the output :
```
{ Export : "Hello world" }
```
but if we did not defined the entry-method path the default method path will be **Require.From.This**

for example :
```
require = require('reqplus');
var obj = require({
            file: 'test.cs',
            encoding: 'utf-8',
            pars: { name : "Hello world"}
        });

console.log(obj);
```
the result :
```
{ This : "Hello world" }
```

java file :
```
package SomeNS;   
import java.util.*;

public class SomeClass 
{
    public static Object SomeMethod(AbstractMap sbject)
    {
        return new obj(
            (String)sbject.get("name")
            );
    }
}

class obj 
{ 
    public obj(String _name){ name = _name;  } 
    public String name; 
}
```
vb file :
```
Imports System

Namespace someNS
    Public Class test
        Public Shared Function Export([global] As Object) As Object
            Return New With { _
                Key .name = global.name _
            }
        End Function
    End Class
End Namespace

Namespace Require
    Public Class From
        Public Shared Function This([global] As Object) As Object
            Return New With { _
                Key .name = global.name _
            }
        End Function
    End Class
End Namespace
```
php file :
```
<?php namespace SomeNS; //optional

class SomeClass {
    public static function SomeMethod($glob){
        return $glob->name;
    }
}

?>
```
**Note : ** namespace & class is optional in php
for example : in this case the entry-method path will be just the name of the function to be 'SomeMethod'
```
function SomeMethod($glob){
    return $glob->name;
}
```
from javascript:
```
require({
            file: 'test.php',
            pars: { name : "Hello world"}
        });
```
**Note : ** encoding is not required for php
___
Meta values
-
you also can define some options for the source file:
by adding commented area at the top of the source file contains lines in key@value format

**This table contains the current keys of meta values and it's descriptions**
Key       | Description |                                             | Supported in
--------  | ---                                                       | 
start     | the entry-method path                                     | vb , c# & java
ref       | path to a reference library (not supported for java yet)  | vb , c#
encoding = charset   | the name of the charset of the source file                | vb , c# & java

**Example**:
This syntax is supported by all languages except php
```
/**
*start@someNS.SomeClass.SomeMethod
*ref@c:\\Newtonsoft.Json.dll
*charset@ascii
*/
```
additional syntax for c# 
```
#region meta
//start@someNS.SomeClass.SomeMethod
//ref@c:\\Newtonsoft.Json.dll
//charset@ascii
#endregion
```
additional syntax for vb
```
#Region "meta"
'start@someNS.SomeClass.SomeMethod
'ref@c:\\Newtonsoft.Json.dll
'charset@ascii
'End Region
```

>**Rules**
>-the signature of the entry-method path for .Net must be
>**public static dynamic (dynamic )**
>-for java is :
>**public static Object (AbstractMap )**
>- or
>**public static AbstractMap (AbstractMap )**
>- supported files are : cs , vb , java , php , dll , jar
>- the default entry-method path = **Require.From.This**
>- the default file encoding = **utf-8**
>- If you already defined the entry method path in meta area of the source file it will ovveride the definition in the javascript
>- you can change the default values by : require.setDefaults(newOptions , trueIfForeverOrFalseForThisSessionOnly);

Donate : 
http://paypal.me/kadioham
Contact : 
kadioham@outlook.com